@@ -218,7 +218,7 @@ pub mod wasm_test {
                 cell_id: alice.cell_id().clone(),
                 zome_name: alice.name().clone(),
                 fn_name: "create_a_thing".into(),
-                cap: None,
+                cap_secret: None,
                 provenance: alice_pubkey.clone(),
                 payload: ExternIO::encode(()).unwrap(),
             })
@@ -234,7 +234,7 @@ pub mod wasm_test {
                 cell_id: alice.cell_id().clone(),
                 zome_name: alice.name().clone(),
                 fn_name: "create_an_invalid_countersigned_thing".into(),
-                cap: None,
+                cap_secret: None,
                 provenance: alice_pubkey.clone(),
                 payload: ExternIO::encode(vec![alice_response.clone(), bob_response.clone()])
                     .unwrap(),
@@ -332,7 +332,7 @@ pub mod wasm_test {
                 cell_id: alice.cell_id().clone(),
                 zome_name: alice.name().clone(),
                 fn_name: "accept_countersigning_preflight_request".into(),
-                cap: None,
+                cap_secret: None,
                 provenance: alice_pubkey.clone(),
                 payload: ExternIO::encode(&preflight_request_2).unwrap(),
             })
@@ -364,7 +364,7 @@ pub mod wasm_test {
                 cell_id: alice.cell_id().clone(),
                 zome_name: alice.name().clone(),
                 fn_name: "create_a_thing".into(),
-                cap: None,
+                cap_secret: None,
                 provenance: alice_pubkey.clone(),
                 payload: ExternIO::encode(()).unwrap(),
             })
@@ -377,7 +377,7 @@ pub mod wasm_test {
                 cell_id: bobbo.cell_id().clone(),
                 zome_name: bobbo.name().clone(),
                 fn_name: "create_a_thing".into(),
-                cap: None,
+                cap_secret: None,
                 provenance: bob_pubkey.clone(),
                 payload: ExternIO::encode(()).unwrap(),
             })
@@ -399,7 +399,7 @@ pub mod wasm_test {
                 cell_id: alice.cell_id().clone(),
                 zome_name: alice.name().clone(),
                 fn_name: "create_a_thing".into(),
-                cap: None,
+                cap_secret: None,
                 provenance: alice_pubkey.clone(),
                 payload: ExternIO::encode(()).unwrap(),
             })
@@ -429,7 +429,7 @@ pub mod wasm_test {
                 cell_id: bobbo.cell_id().clone(),
                 zome_name: bobbo.name().clone(),
                 fn_name: "create_a_thing".into(),
-                cap: None,
+                cap_secret: None,
                 provenance: bob_pubkey.clone(),
                 payload: ExternIO::encode(()).unwrap(),
             })
