@@ -21,7 +21,6 @@ pub mod wasm_test {
     use crate::{sweettest::SweetDnaFile};
     use ::fixt::prelude::*;
     use hdk::prelude::*;
-    use holochain_state::host_fn_workspace::HostFnWorkspace;
     use holochain_types::fixt::CapSecretFixturator;
     use holochain_types::prelude::*;
     use holochain_types::test_utils::fake_agent_pubkey_1;
@@ -33,36 +32,16 @@ pub mod wasm_test {
     #[tokio::test(flavor = "multi_thread")]
     async fn ribosome_capability_secret_test<'a>() {
         observability::test_run().ok();
-        // test workspace boilerplate
-        let test_env = holochain_state::test_utils::test_cell_env();
-        let test_cache = holochain_state::test_utils::test_cache_env();
-        let env = test_env.env();
-        let author = fake_agent_pubkey_1();
-        crate::test_utils::fake_genesis(env.clone())
-            .await
-            .unwrap();
-        let workspace = HostFnWorkspace::new(env.clone(), test_cache.env(), author).await.unwrap();
-        let mut host_access = fixt!(ZomeCallHostAccess);
-        host_access.workspace = workspace.clone();
+        let host_access = fixt!(ZomeCallHostAccess, Predictable);
 
-        let _output: CapSecret =
+        let _: CapSecret =
             crate::call_test_ribosome!(host_access, TestWasm::Capability, "cap_secret", ()).unwrap();
     }
 
     #[tokio::test(flavor = "multi_thread")]
     async fn ribosome_transferable_cap_grant<'a>() {
         observability::test_run().ok();
-        // test workspace boilerplate
-        let test_env = holochain_state::test_utils::test_cell_env();
-        let test_cache = holochain_state::test_utils::test_cache_env();
-        let env = test_env.env();
-        let author = fake_agent_pubkey_1();
-        crate::test_utils::fake_genesis(env.clone())
-            .await
-            .unwrap();
-        let workspace = HostFnWorkspace::new(env.clone(), test_cache.env(), author).await.unwrap();
-        let mut host_access = fixt!(ZomeCallHostAccess);
-        host_access.workspace = workspace.clone();
+        let host_access = fixt!(ZomeCallHostAccess, Predictable);
 
         let secret: CapSecret =
             crate::call_test_ribosome!(host_access, TestWasm::Capability, "cap_secret", ()).unwrap();
