@@ -2,6 +2,7 @@
 
 use anyhow::Result;
 use holochain::conductor::ConductorHandle;
+use holochain_conductor_api::FullStateDump;
 use holochain_websocket::WebsocketReceiver;
 use holochain_websocket::WebsocketSender;
 
@@ -159,7 +160,7 @@ pub async fn register_and_install_dna(
     agent_key: AgentPubKey,
     dna_path: PathBuf,
     properties: Option<YamlProperties>,
-    nick: String,
+    role_id: AppRoleId,
     timeout: u64,
 ) -> DnaHash {
     register_and_install_dna_named(
@@ -168,7 +169,7 @@ pub async fn register_and_install_dna(
         agent_key,
         dna_path,
         properties,
-        nick,
+        role_id,
         "test".to_string(),
         timeout,
     )
@@ -181,7 +182,7 @@ pub async fn register_and_install_dna_named(
     agent_key: AgentPubKey,
     dna_path: PathBuf,
     properties: Option<YamlProperties>,
-    nick: String,
+    role_id: AppRoleId,
     name: String,
     timeout: u64,
 ) -> DnaHash {
@@ -202,7 +203,7 @@ pub async fn register_and_install_dna_named(
 
     let dna_payload = InstallAppDnaPayload {
         hash: dna_hash.clone(),
-        nick,
+        role_id,
         membrane_proof: None,
     };
     let payload = InstallAppPayload {
@@ -288,3 +289,23 @@ async fn check_timeout_named<T>(
         }
     }
 }
+
+pub async fn dump_full_state(
+    client: &mut WebsocketSender,
+    cell_id: CellId,
+    dht_ops_cursor: Option<u64>,
+) -> FullStateDump {
+    let request = AdminRequest::DumpFullState {
+        cell_id: Box::new(cell_id),
+        dht_ops_cursor,
+    };
+    let response = client.request(request);
+    let response = check_timeout(response, 3000).await;
+
+    let full_state = match response {
+        AdminResponse::FullStateDumped(state) => state,
+        _ => panic!("DumpFullState failed: {:?}", response),
+    };
+
+    full_state
+}
